@@ -9,8 +9,8 @@
 ;;             Bozhidar Batsov <bozhidar@batsov.dev>
 ;; URL: https://github.com/copilot-emacs/copilot.el
 ;; Package-Requires: ((emacs "27.2") (editorconfig "0.8.2") (jsonrpc "1.0.14") (compat "30") (track-changes "1.4"))
-;; Package-Version: 20260218.1316
-;; Package-Revision: 3be3a09d0696
+;; Package-Version: 20260219.2146
+;; Package-Revision: a62c1a573371
 ;; Keywords: convenience copilot
 
 ;; The MIT License (MIT)
@@ -148,6 +148,14 @@ find indentation offset."
   :type 'boolean
   :package-version '(copilot . "0.1"))
 
+(defcustom copilot-enable-parentheses-balancer t
+  "Whether to post-process completions to balance parentheses in Lisp modes.
+When non-nil, completions in Lisp modes are adjusted to ensure that
+parentheses remain balanced within the surrounding top-level form.
+Set to nil to use completions from the server verbatim."
+  :type 'boolean
+  :group 'copilot)
+
 (defcustom copilot-indentation-alist
   (append '((emacs-lisp-mode lisp-indent-offset)
             (latex-mode tex-indent-basic)
@@ -1289,7 +1297,9 @@ provided."
           (insert t-completion))
         ;; if it is a partial completion, show remaining text
         (when is-partial
-          (copilot--set-overlay-text (copilot--get-overlay) (string-remove-prefix t-completion completion))))
+          (let ((ov (copilot--get-overlay)))
+            (overlay-put ov 'tail-length (- (line-end-position) (point)))
+            (copilot--set-overlay-text ov (string-remove-prefix t-completion completion)))))
       t)))
 
 (defmacro copilot--define-accept-completion-by-action (func-name action)
